@@ -540,6 +540,12 @@ fu_device_set_version_lowest(FuDevice *self, const gchar *version);
 void
 fu_device_set_version_bootloader(FuDevice *self, const gchar *version);
 void
+fu_device_add_backend_tag(FuDevice *self, const gchar *backend_tag);
+gboolean
+fu_device_has_backend_tag(FuDevice *self, const gchar *backend_tag);
+GPtrArray *
+fu_device_get_backend_tags(FuDevice *self);
+void
 fu_device_inhibit(FuDevice *self, const gchar *inhibit_id, const gchar *reason);
 void
 fu_device_uninhibit(FuDevice *self, const gchar *inhibit_id);
@@ -585,6 +591,10 @@ guint
 fu_device_get_remove_delay(FuDevice *self);
 void
 fu_device_set_remove_delay(FuDevice *self, guint remove_delay);
+guint
+fu_device_get_acquiesce_delay(FuDevice *self);
+void
+fu_device_set_acquiesce_delay(FuDevice *self, guint acquiesce_delay);
 void
 fu_device_set_firmware_size(FuDevice *self, guint64 size);
 void
@@ -722,6 +732,8 @@ gboolean
 fu_device_has_private_flag(FuDevice *self, guint64 flag);
 void
 fu_device_emit_request(FuDevice *self, FwupdRequest *request);
+FwupdSecurityAttr *
+fu_device_security_attr_new(FuDevice *self, const gchar *appstream_id);
 
 void
 fu_device_add_instance_str(FuDevice *self, const gchar *key, const gchar *value);
